--AH:ScriptId=1A4531D4-2B27-4E80-87DE-AEB658044864

CREATE TABLE [ApiKeyTasks]
(
    [ApiKeyTask_Id] INT IDENTITY(1, 1) NOT NULL,
    [ApiKey_Id] INT NOT NULL,
    [Feed_Id] INT NULL,
    [FeedGroup_Id] INT NULL,
    [Task_Id] INT NOT NULL,

    CONSTRAINT [PK__ApiKeyTasks]
        PRIMARY KEY ([ApiKeyTask_Id]),

    CONSTRAINT [FK__ApiKeyTasks__ApiKeys]
        FOREIGN KEY ([ApiKey_Id])
            REFERENCES [ApiKeys] ([ApiKey_Id])
            ON DELETE CASCADE,

    CONSTRAINT [FK__ApiKeyTasks__Feeds]
        FOREIGN KEY ([Feed_Id])
            REFERENCES [Feeds] ([Feed_Id])
            ON DELETE CASCADE,

    CONSTRAINT [FK__ApiKeyTasks__FeedGroups]
        FOREIGN KEY ([FeedGroup_Id])
            REFERENCES [FeedGroups] ([FeedGroup_Id])
            ON DELETE CASCADE,

    CONSTRAINT [FK__ApiKeyTasks__Tasks]
        FOREIGN KEY ([Task_Id])
            REFERENCES [Tasks] ([Task_Id]),

    CONSTRAINT [CK__ApiKeyTasks__Scope]
        CHECK ([Feed_Id] IS NULL OR [FeedGroup_Id] IS NULL),

    CONSTRAINT [UQ__ApiKeyTasks]
        UNIQUE ([ApiKey_Id], [Feed_Id], [FeedGroup_Id], [Task_Id])
)
GO

CREATE TYPE [ApiKeyTaskEntry] AS TABLE
(
    [Feed_Id] INT NULL,
    [FeedGroup_Id] INT NULL,
    [Task_Id] INT NOT NULL
)
GO

GRANT EXECUTE ON TYPE::[ApiKeyTaskEntry] TO [ProGetUser_Role]
GO

-- populate defaults to maintain compatibility with previous behavior
INSERT INTO [ApiKeyTasks]
(
    [ApiKey_Id],
    [Task_Id]
)
SELECT AK.[ApiKey_Id],
       T.[Task_Id]
  FROM [ApiKeys] AK
       JOIN [Tasks] T ON T.[Task_Name] IN ('Feeds_ViewFeed', 'Feeds_DownloadPackage', 'Feeds_DeletePackage', 'Feeds_AddPackage', 'Feeds_OverwritePackage')
 WHERE [ApiKey_Configuration].exist('//Inedo.ProGet.ApiKeys.ApiKey/Properties[@AllowFeedApi="True"]') = 1
