EXEC [dbo].[__AddStoredProcInfo]
    /* StoredProc_Name         */ 'Assets_CreateOrUpdateUserMetadataEntry',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ NULL,
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates a user-defined metadata entry for an asset item.'
GO

IF OBJECT_ID('[Assets_SetOrClearUserMetadata]') IS NOT NULL DROP PROCEDURE [Assets_SetOrClearUserMetadata]
GO
IF OBJECT_ID('[Assets_CreateOrUpdateUserMetadataEntry]') IS NOT NULL DROP PROCEDURE [Assets_CreateOrUpdateUserMetadataEntry]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [Assets_CreateOrUpdateUserMetadataEntry]
(
	@AssetItem_Id INT,
	@Key_Name VARCHAR(50),
	@Value_Text NVARCHAR(MAX),
	@IncludeInResponseHeader_Indicator YNINDICATOR,
	@SetModifiedDate_Indicator YNINDICATOR = 'Y'
)
AS
BEGIN

	SET NOCOUNT ON

	IF EXISTS(SELECT * FROM [AssetItemMetadata] WHERE [AssetItem_Id] = @AssetItem_Id AND [Key_Name] = @Key_Name)
	BEGIN

		UPDATE [AssetItemMetadata]
		   SET [Value_Text] = @Value_Text,
		       [IncludeInResponseHeader_Boolean] = CASE WHEN @IncludeInResponseHeader_Indicator = 'Y' THEN 1 ELSE 0 END
		 WHERE [AssetItem_Id] = @AssetItem_Id
		   AND [Key_Name] = @Key_Name
	END
	ELSE
	BEGIN

		INSERT INTO [AssetItemMetadata]
		(
			[AssetItem_Id],
			[Key_Name],
			[Value_Text],
			[IncludeInResponseHeader_Boolean]
		)
		VALUES
		(
			@AssetItem_Id,
			@Key_Name,
			@Value_Text,
			CASE WHEN @IncludeInResponseHeader_Indicator = 'Y' THEN 1 ELSE 0 END
		)

	END

	IF @SetModifiedDate_Indicator = 'Y' BEGIN

		UPDATE [AssetItems]
		   SET [Modified_Date] = GETUTCDATE()
		 WHERE [AssetItem_Id] = @AssetItem_Id

	END

	DECLARE @Feed_Id INT = (SELECT [Feed_Id] FROM [AssetItems] WHERE [AssetItem_Id] = @AssetItem_Id)

	UPDATE [Feeds]
	   SET [FeedState_Number] = COALESCE([FeedState_Number], 0) + 1
	 WHERE [Feed_Id] = @Feed_Id

END
GO

GRANT EXECUTE ON [Assets_CreateOrUpdateUserMetadataEntry] TO [ProGetUser_Role]