EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'DockerImages_SetTag',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates or updates a tag.'
GO

IF OBJECT_ID('[DockerImages_SetTag]') IS NOT NULL DROP PROCEDURE [DockerImages_SetTag]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [DockerImages_SetTag]
(
	@DockerRepository_Id INT,
	@DockerImage_Id INT,
	@Tag_Name VARCHAR(128),
	@Comments_Text NVARCHAR(MAX) = NULL,
	@Created_Date DATETIME = NULL
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [DockerRepositoryTags] WHERE [DockerRepository_Id] = @DockerRepository_Id AND [Tag_Name] = @Tag_Name)

		UPDATE [DockerRepositoryTags]
		   SET [DockerImage_Id] = @DockerImage_Id,
		       [Created_Date] = COALESCE(@Created_Date, GETUTCDATE()),
			   [Comments_Text] = @Comments_Text,
			   [CreatedBy_User_Name] = dbo.Session_GetUserName()
		 WHERE [DockerRepository_Id] = @DockerRepository_Id
		   AND [Tag_Name] = @Tag_Name

	ELSE

		INSERT INTO [DockerRepositoryTags]
		(
			[DockerRepository_Id],
			[Tag_Name],
			[DockerImage_Id],
			[Comments_Text],
			[Created_Date],
			[CreatedBy_User_Name]
		)
		VALUES
		(
			@DockerRepository_Id,
			@Tag_Name,
			@DockerImage_Id,
			@Comments_Text,
			COALESCE(@Created_Date, GETUTCDATE()),
			dbo.Session_GetUserName()
		)

		COMMIT

END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [DockerImages_SetTag] TO [ProGetUser_Role]
GO