EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'MavenArtifacts_SetReleaseVersion',
    /* Internal_Indicator      */ 'Y',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Updates the release version of the specified Maven artifact.'
GO

IF OBJECT_ID('[MavenArtifacts_SetReleaseVersion]') IS NOT NULL DROP PROCEDURE [MavenArtifacts_SetReleaseVersion]
GO

SET QUOTED_IDENTIFIER ON
GO
SET ANSI_NULLS ON
GO

CREATE PROCEDURE [MavenArtifacts_SetReleaseVersion]
(
	@Feed_Id INT,
	@GroupId_Text NVARCHAR(200),
	@ArtifactId_Text NVARCHAR(100),
	@ReleaseVersion_Text NVARCHAR(50)
)
AS
BEGIN

SET NOCOUNT ON
SET QUOTED_IDENTIFIER ON

BEGIN TRY
	BEGIN TRANSACTION

	DECLARE @MavenArtifact_Id INT
	SET @MavenArtifact_Id = (SELECT [MavenArtifact_Id]
	                           FROM [MavenArtifacts]
							   WITH (UPDLOCK)
							  WHERE [Feed_Id] = @Feed_Id AND [GroupId_Text] = @GroupId_Text AND [ArtifactId_Text] = @ArtifactId_Text)

	IF @MavenArtifact_Id IS NULL
		RAISERROR('The specified artifact was not found.', 16, 1)

	UPDATE [MavenArtifacts]
	   SET [ReleaseVersion_Text] = @ReleaseVersion_Text
	 WHERE [MavenArtifact_Id] = @MavenArtifact_Id

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH


END
GO

GRANT EXECUTE ON [MavenArtifacts_SetReleaseVersion] TO [ProGetUser_Role]